<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl">
<context>
    <name>PanZoom</name>
    <message>
        <location filename="../PanZoomInit.js" line="+2"/>
        <source>&amp;Pan Zoom</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
&amp;Przesuń-zoom</translatorcomment>
        <translation>&amp;Przesuń przybliżenie</translation>
    </message>
</context>
</TS>
